import { APIClient } from "./ApiClient";
import { Device, DeviceRelay } from "./DeviceApi";

export class RelayApi {
  /**
   * Get the full list of relays
   */
  static async GetList(): Promise<DeviceRelay[]> {
    return (
      await APIClient.exec({
        method: "GET",
        uri: "/relays/list",
      })
    ).data;
  }

  /**
   * Create a new relay
   */
  static async Create(device: Device, relay: DeviceRelay): Promise<void> {
    await APIClient.exec({
      method: "POST",
      uri: "/relay/create",
      jsonData: {
        ...relay,
        id: undefined,
        device_id: device.id,
      },
    });
  }

  /**
   * Update a relay information
   */
  static async Update(relay: DeviceRelay): Promise<void> {
    await APIClient.exec({
      method: "PUT",
      uri: `/relay/${relay.id}`,
      jsonData: relay,
    });
  }
}
